@@ -1,8 +1,15 @@
 import enum
+from typing import override
 
 from . import flags
 
 
+class WialonMeasurementUnit(enum.IntEnum):
+    METRIC = 0
+    US = 1
+    IMPERIAL = 2
+
+
 class WialonItemsType(enum.StrEnum):
     """
     Wialon item types for Wialon API calls.
@@ -108,6 +115,10 @@ class WialonItemProperty(enum.StrEnum):
     UNIQUE_ID = "sys_unique_id"
     """Object unique id."""
 
+    @override
+    def __add__(self, other: str) -> str:
+        return ",".join([super().__str__(), str(other)])
+
 
 ACCESSMASK_RESOURCE_BASIC: int = sum(
     [
