@@ -98,14 +98,33 @@ class WialonSession:
             logging.getLogger(self.__class__.__name__), level=log_level
         ).get_logger()
 
+    def __str__(self) -> str:
+        return str(self.id)
+
+    def __repr__(self) -> str:
+        return f"{self.__class__}(sid={self.id})"
+
     def __enter__(self) -> "WialonSession":
-        """Logs into the Wialon API using a token set in :py:meth:`__init__`."""
+        """
+        Logs into the Wialon API using :py:meth:`login`.
+
+        :raises AssertionError: If the Wialon API token was not set.
+        :returns: A valid Wialon API session.
+        :rtype: :py:obj:`~terminusgps.wialon.session.WialonSession`
+
+        """
         assert self.token, "Wialon API token was not set"
         self.login(self.token)
         return self
 
     def __exit__(self, exc_type, exc_value, exc_traceback) -> None:
-        """Logs out of the session by calling :py:meth:`logout`."""
+        """
+        Logs out of the session by calling :py:meth:`logout`.
+
+        :returns: Nothing.
+        :rtype: :py:obj:`None`
+
+        """
         self.logout()
 
     @property
